package com.spring.series.aop.advice;

import java.lang.reflect.Method;

import org.springframework.aop.ThrowsAdvice;

public class AfterThrowingAdviceInterceptor implements ThrowsAdvice {

	/**
	 * one of the way to specify method for afterThrowing advice
	 * 
	 * @param illegalArgumentException
	 * @throws Throwable
	 */
	public void afterThrowing(IllegalArgumentException illegalArgumentException) throws Throwable {
		System.out.println("******** AfterThrowingAdvice ********");
	}

	/**
	 * other way to specify method for afterThrowing advice & more matured
	 * 
	 * @param method
	 * @param args
	 * @param target
	 * @param exception
	 */
	public void afterThrowing(Method method, Object args[], Object target, Exception exception) {
		System.out.println("******** AfterThrowingAdvice : " + method.getName() + " ********");
	}

	/**
	 * poincut expression
	 * 
	 * this is method is invoked from the pointcut expression declared in the spring context xml
	 */
	public void afterThrowingAdviceUsingPointcutExpression() {
		System.out.println("******** After Throwing Advice using Pointcut Expression ********");
	}
}